--[[
	CS_AttackHistDB.lua - Is a support module file for the CombatStats
	World of Warcraft addon.  This module is the data base functionality
	to store, restore, and save the attack history data information.
	
	Copyright (C) 2008 Brian Beardmore - wowaddon(at)realisticsoftware(dot)com

	Revisions:
		2007.11.23 BAB	Fixed the Clear DB function to also clear the attackName list
		2007.08.26 BAB	Created by Brian Beardmore
						
	License:
		This program is free software; you can redistribute it and/or
		modify it under the terms of the GNU General Public License
		as published by the Free Software Foundation; either version 2
		of the License, or (at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program(see GPL.txt); if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
]]

-- Debug switch - set to true, to enable debug output for this module
local debug = false;

-------------------------------------------------------------------------------
-- Uses and requires
-------------------------------------------------------------------------------
	-- CombatStats.Utils..

-------------------------------------------------------------------------------
-- Function Imports
-------------------------------------------------------------------------------
local debugPrint = CombatStats.Utils.DebugPrint;

-------------------------------------------------------------------------------
-- Function Prototypes
-------------------------------------------------------------------------------
local load;

local loadAttackNames;
local clearAttackNames;
local getAttackNameIdx;
local addAttackName;
local remAttackName;
local getGroupNameForAttackName;
local getAttackNameCount;
local getAttackName;
local callFunctionForEachAttackName;
local callFunctionForEachAttackNameRev;
local sortAttackNames;
local setGrpSortType;

local loadAttacksDB;
local createAttacksDB;
local clearAttacksDB;
local countAttacksDB;
local getAttackRec;
local addCreateAttackRec;
local clearRecFromAttacksDB;


-------------------------------------------------------------------------------
-- Data Members
-------------------------------------------------------------------------------
-- The attacks database is saved on disk. Nobody should access this
-- variable outside of the loadAttacksDB() method. Instead the _L.DB
-- variable should be used.
specialAttacks = nil;

local _L = {
	DB = nil,
	
	attackNameList = nil,			-- a sorted list of all the attack names in the DB
	attackNameSortDirty = false,	-- set to true when sometime about the attack name list has changed
	grpSortType = 0,
};

-------------------------------------------------------------------------------
-- Constants
-------------------------------------------------------------------------------



-------------------------------------------------------------------------------
-- Loads this module.
-------------------------------------------------------------------------------
function load()
	loadAttacksDB();
end

--=============================================================================
-- attackNames management functions
--=============================================================================

function clearAttackNames()
	_L.attackNameList = {};
end

-------------------------------------------------------------------------------
-- Upgrades the attackNames. If it does not exist it creates a new one.
-------------------------------------------------------------------------------
function loadAttackNames()
	local iAttackName;
	
	clearAttackNames();
	for iAttackName, _ in pairs(_L.DB) do
		addAttackName(iAttackName, false);
	end
end

-------------------------------------------------------------------------------
-- getAttackNameIdx
-------------------------------------------------------------------------------
function getAttackNameIdx(attackName)
-- one base indexs, so 0 is not found
	if (not attackName) then return 0; end
	local i = 0;
	local lookupName;
	
	for _, lookupName in pairs(_L.attackNameList) do
		i = i + 1;
		if (lookupName == attackName) then
			return i;
			--break;
		end
	end
	
	return 0;
end

-------------------------------------------------------------------------------
-- addAttackName
-------------------------------------------------------------------------------
function addAttackName(attackName, allowDups)
	if (not attackName) then return 0; end
	local	attackIdx = getAttackNameIdx(attackName);
	allowDups = allowDups or false;
	
	if ((not allowDups) and (attackIdx > 0)) then return; end
	
	table.insert(_L.attackNameList, attackName);
	
	_L.attackNameSortDirty = true;
end

-------------------------------------------------------------------------------
-- remAttackName
-------------------------------------------------------------------------------
function remAttackName(attackName)
	if (not attackName) then return; end
	local	attackIdx = getAttackNameIdx(attackName);
	
	if (attackIdx > 0) then
		table.remove(_L.attackNameList, attackIdx);
	end
end

-------------------------------------------------------------------------------
-- getGroupNameForAttackName
-------------------------------------------------------------------------------
function getGroupNameForAttackName(attackName, grpType)
	if (not attackName) then return ""; end
	grpType = grpType or _L.grpSortType;
	local aStr;
	local endidx, s1, e1, s2, e2;
	
	aStr = nil;
	s1 = nil;
	s2 = nil;
	endidx = 0;
	
	if(grpType == 1) then
		s1, e1 = string.find(attackName, "^%[%w*%]");
	end
	
	if (s1 ~= nil) then
		aStr = string.sub(attackName, 1, e1+1);
	else
		s1, e1 = string.find(attackName, "%s%[");
		s2, e2 = string.find(attackName, "%s%(");
		if (s1 ~= nil) then
			endidx = e1;
		end
		if ((s2 ~= nil) and (e2 < endidx)) then
			endidx = e2;
		end
		if (endidx > 2) then
			if (string.sub(attackName, endidx-2, endidx-2) ~= '.')
			then
				aStr = string.sub(attackName, 1, endidx-1);
			else
				aStr = string.sub(attackName, 1, endidx-3).." ";
			end
		end
	end
	
	return(aStr);
end

-------------------------------------------------------------------------------
-- getAttackNameCount
-------------------------------------------------------------------------------
function getAttackNameCount()
	return table.getn(_L.attackNameList);
end

-------------------------------------------------------------------------------
-- getAttackName
-------------------------------------------------------------------------------
function getAttackName(theIndex)
	return _L.attackNameList[theIndex];
end

-------------------------------------------------------------------------------
-- callFunctionForEachAttackName
-------------------------------------------------------------------------------
function callFunctionForEachAttackName(callFunction,...)
	local i;
	local attackName;
	
	for i, attackName in pairs(_L.attackNameList) do
		callFunction(attackName, ...);
	end

end

-------------------------------------------------------------------------------
-- callFunctionForEachAttackNameRev
-------------------------------------------------------------------------------
function callFunctionForEachAttackNameRev(callFunction,...)
	local i;

	for i=getAttackNameCount(), 1, -1 do
		callFunction(getAttackName(i), ...);
	end
end

-------------------------------------------------------------------------------
-- sortAttackNames
-------------------------------------------------------------------------------
function sortAttackNames(sortFunction)
	table.sort(_L.attackNameList, sortFunction);
end

-------------------------------------------------------------------------------
-- setGrpSortType
-------------------------------------------------------------------------------
function setGrpSortType(theType)
	_L.grpSortType = theType;
end
	
--=============================================================================
-- Database management functions
--=============================================================================

-------------------------------------------------------------------------------
-- Upgrades the database. If the database does not exist
-- it creates a new one.  It also creates the local attackNames list
-------------------------------------------------------------------------------
function loadAttacksDB()
	-- Create the root DB, if needed.
	if (not specialAttacks) then
		specialAttacks = createAttacksDB();
		debugPrint("Created _L.DB database");
	end

	-- Upgrade database, if needed.
	
	-- Make specialAttacks the local database
	_L.DB = specialAttacks;
	
	-- create the attackNames quick list
	loadAttackNames();
	attackNameSortDirty = true;
end


-------------------------------------------------------------------------------
-- Creates a new database.
-------------------------------------------------------------------------------
function createAttacksDB()
	return {};
end

-------------------------------------------------------------------------------
-- Clear database.
-------------------------------------------------------------------------------
function clearAttacksDB()
	_L.DB = {};
	clearAttackNames();
end

-------------------------------------------------------------------------------
-- Database count
-------------------------------------------------------------------------------
function countAttacksDB()
	return(table.getn(_L.DB));
end

-------------------------------------------------------------------------------
-- newAttackRec
-------------------------------------------------------------------------------
function newAttackRec(attackName, aIndex)
	return {
			index				=	aIndex,
			name				=	attackName,
			group				=	nil,
			isDOT				=	0,
			dotDmg				=	0,
			dotTicks			=	0,
			totalSwings			=	0,
			totalMisses			=	0,
			totalDodged			=	0,
			totalParried		=	0,
			totalEvaded			=	0,
			totalBlocked		=	0,
			totalResisted		=	0,
			totalImmuned		=	0,
			totalDeflected		=	0,
			totalHits			=	0,
			totalNonCrits		=	0,
			totalCrits			=	0,
			minCrit				=	0,
			minCritTime			=	0,
			maxCrit				=	0,
			maxCritTime			=	0,
			minReg				=	0,
			minRegTime			=	0,
			maxReg				=	0,
			maxRegTime			=	0,
			totalRegDmg			=	0,
			totalCritDmg		=	0,
			lastCrit			=	0,
			lastUpdate			=	0,
		}
end

-------------------------------------------------------------------------------
-- Gets the Attack Data database for a specified Attack Name.
-------------------------------------------------------------------------------
function getAttackRec(attackName, create, includeInNameList)
	create = create or false
	includeInNameList = includeInNameList or false
	-- attackName must be provided
	if (attackName == nil) then debugPrint("attackName NIL!"); return nil; end
	
	local attackData = _L.DB[attackName];
	if ((attackData == nil) and create) then
		attackData = addCreateAttackRec(attackName,includeInNameList);
	end
	
	if ((attackData == nil) and create) then
		debugPrint("_L.DB["..attackName.."] is nil!");
	end
	return attackData;
end


-------------------------------------------------------------------------------
-- Add a new empty Attack Data database entry for a specified Attack Name.
-------------------------------------------------------------------------------
function addCreateAttackRec(attackName, includeInNameList)
	-- attackName must be provided
	if (attackName == nil) then debugPrint("attackName NIL!"); return nil; end
	
	local attackData = newAttackRec(attackName,0);
	_L.DB[attackName] = attackData;
	debugPrint("Created _L.DB["..attackName.."]");
	
	if ((attackData ~= nil) and (includeInNameList)) then 
		addAttackName(attackName, false);
		attackData.group = getGroupNameForAttackName(attackName, 0);
	end
	
	return attackData;
end

-------------------------------------------------------------------------------
-- clearRecFromAttacksDB
-------------------------------------------------------------------------------
function clearRecFromAttacksDB(attackName)
	local attackData = getAttackRec(attackName, false);
	
	if (attackData) then
		_L.DB[attackName] = nil;
		
		remAttackName(attackName);
	else
		-- clearRecFromAttacksDB everything
		specialAttacks = createAttacksDB();
		_L.DB = specialAttacks;
		
		callFunctionForEachAttackName(remAttackName);
	end
end


--=============================================================================
-- Initialization
--=============================================================================
if (CombatStats and CombatStats.AttackHistDB) then return end;
debugPrint("CS_AttackHistDB.lua loaded");

-------------------------------------------------------------------------------
-- Public API
-------------------------------------------------------------------------------
if (not CombatStats) then CombatStats = {}; end

CombatStats.AttackHistDB = {
	Load = load;
	Clear = clearAttacksDB;
--	Count = countAttacksDB;				-- not used
	GetAttackRec = getAttackRec;
	ClearRecFromAttacksDB = clearRecFromAttacksDB;
	
	GetAttackNameCount = getAttackNameCount;
	GetAttackNameIdx = getAttackNameIdx;
	GetAttackName = getAttackName;
	GetGroupNameForAttackName = getGroupNameForAttackName;
	CallFunctionForEachAttackName = callFunctionForEachAttackName;
	CallFunctionForEachAttackNameRev = callFunctionForEachAttackNameRev;
	SortAttackNames = sortAttackNames;
	SetGrpSortType = setGrpSortType;
}

-------------------------------------------------------------------------------
-- Create an empty database to use before any load or update is performed.
-------------------------------------------------------------------------------
specialAttacks = createAttacksDB();
_L.DB = specialAttacks;

loadAttackNames();		-- <-- this should not be required but if createAttacksDB changes then it may
