--[[
	CS_CombatParse.lua - Is a support module file for the CombatStats
	World of Warcraft addon.  This modules functionality is to support all the 
	combat battle parsing.  This module supports combat text parsing of all
	the blizzard supported languages by using the blizzard string globals.
	
	Copyright (C) 2008 Brian Beardmore - wowaddon(at)realisticsoftware(dot)com

	Revisions:
		2008.01.18 BAB	fixed the _L.cp.aio entries for Healing parses
		2007.08.26 BAB	revised in all prior version until moving to this file
		2007.06.08 BAB	Original created by Brian Beardmore
						
	License:
		This program is free software; you can redistribute it and/or
		modify it under the terms of the GNU General Public License
		as published by the Free Software Foundation; either version 2
		of the License, or (at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program(see GPL.txt); if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
]]

-- Debug switch - set to true, to enable debug output for this module
local debug = false;


-------------------------------------------------------------------------------
-- Function Imports
-------------------------------------------------------------------------------
local debugPrint = CombatStats.Utils.DebugPrint;

-------------------------------------------------------------------------------
-- Function Prototypes
-------------------------------------------------------------------------------
local load;

local parseCombatEvent;
local loadCombatParsePhases;
local setParseAttackInfoOrder;
local fixCombatParsePhase;
local fixAllCombatParsePhases;

-------------------------------------------------------------------------------
-- Data Members
-------------------------------------------------------------------------------

local _L = {
	cp = {
		p = {},			-- attack strings match array
		o = {},			-- index order array for each attack string match array item
		
		aio = {
			--	attack info order (for each attack type there is an parse order ie attackType=5 order is spell, creatureName, damage)
			-- [5] = 	creatureName = 2,
			--			damage = 3,
			--			damageType = 0,
			--			spell = 1,
			--			petName = 0,
			--			healP = 0,
			--OR [5] = {2,3,0,1,0,0}
		},
	},
	tmpStrArr = {},
	
};

-------------------------------------------------------------------------------
-- Constants
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- Uses
-------------------------------------------------------------------------------
	-- Lots of Blizzard globals - i.e.  SPELLDODGEDOTHEROTHER
	
-------------------------------------------------------------------------------
-- Loads this module.
-------------------------------------------------------------------------------
function load()
	if (_L.cp.p[1] ~= nil) then return; end		-- already loaded
	loadCombatParsePhases()
	setParseAttackInfoOrder()
end

--=============================================================================
-- ?? functions
--=============================================================================

-------------------------------------------------------------------------------
-- fixCombatParsePhase
-------------------------------------------------------------------------------
function fixCombatParsePhase(theText)
	local	newText = nil
	local	num = 0
	local	w
	local	counter = 0
	local	orderArr = {}
	local	chkorderArr = {}
	
	-- %s --> (.+)
	-- %d --> (%d+)
	-- by %s. --> by (.*).  ? (sometimes)
	-- %s. --> (.*).  ?
	-- other locals have the position order also defined [ %1$s --> (.+) ]
	
	--[[
	newText = theText
	newText = string.gsub(newText, " by %%s%.", " by (.*).")
	newText = string.gsub(newText, "%%s", "(.+)")
	newText = string.gsub(newText, "%%d", "(%%d+)")
	-- strip end '.'
	newText = string.gsub(newText, "%.$", "")
	]]
	
	newText = theText
	--cs_print("newText (before): "..newText)
	
	-- find or setup the match order
	counter = 1
	for num, w in string.gmatch(newText, "%%([0-9]-)%$-([sd])") do
		num = tonumber(num)
		num = num or counter
		if (num <1) then num = counter end
		-- w = w or "" cs_print("num: "..num.." w: "..w)		-- DEBUG
		orderArr[counter] = num
		counter = counter + 1
	end
	
	-- check the order array for errors
	chkorderArr = orderArr
	table.sort(chkorderArr)
	for i, num in pairs(chkorderArr) do
		if (i ~= num) then
			cs_print("ERR: -- critical error -- parse index is")
			cs_print("    missing for '"..theText.."'")
			cs_print("    Contact the person maintaining this addon with this information")
		end
	end
	
	-- change the %s and %d 's
	newText = string.gsub(newText, " %%[0-9]-%$-s%.$", " (.*).")	-- special for end
	newText = string.gsub(newText, "%%[0-9]-%$-s", "(.+)")			-- for end %s & %X$s
	newText = string.gsub(newText, "%%[0-9]-%$-d", "(%%d+)")		-- for end %d & %X$d
	-- strip end '.'
	newText = string.gsub(newText, "%.$", "")
	--cs_print("newText (after): "..newText)
	
	return newText, orderArr
end

-------------------------------------------------------------------------------
-- fixAllCombatParsePhases
-------------------------------------------------------------------------------
function fixAllCombatParsePhases()
	for i=1, table.getn(_L.cp.p) do
		_L.cp.p[i], _L.cp.o[1] = fixCombatParsePhase(_L.cp.p[i])
		--cs_print ("_L.cp.o["..i.."] = {"..CombatStats_DumpArrayString(_L.cp.o[i]).."}; _L.cp.p["..i.."] = ".._L.cp.p[i])
	end
end

-------------------------------------------------------------------------------
-- loadCombatParsePhases
-------------------------------------------------------------------------------
function loadCombatParsePhases()
	--[[
		-- this is only for testing only, it can be deleted
	for i=1, 63 do _L.cp.p[i] = "" _L.cp.o[i] = {} end
	_L.cp.p[1], _L.cp.o[1] = fixCombatParsePhase(PERIODICAURADAMAGESELFOTHER)
	cs_print ("_L.cp.o[1] = {"..CombatStats_DumpArrayString(_L.cp.o[1]).."}; _L.cp.p[1] = ".._L.cp.p[1])
	_L.cp.p[2], _L.cp.o[2]  = fixCombatParsePhase(GE_PERIODICAURADAMAGESELFOTHER)
	cs_print ("_L.cp.o[2] = {"..CombatStats_DumpArrayString(_L.cp.o[2]).."}; _L.cp.p[2] = ".._L.cp.p[2])
	_L.cp.p[3], _L.cp.o[3]  = fixCombatParsePhase(FR_PERIODICAURADAMAGESELFOTHER)
	cs_print ("_L.cp.o[3] = {"..CombatStats_DumpArrayString(_L.cp.o[3]).."}; _L.cp.p[3] = ".._L.cp.p[3])
	if (true) then return end
	]]
	
	_L.cp.p[1], _L.cp.o[1] = fixCombatParsePhase(PERIODICAURADAMAGESELFOTHER)
		_L.cp.p[2], _L.cp.o[2] = fixCombatParsePhase(SPELLLOGSELFOTHER)
		_L.cp.p[3], _L.cp.o[3] = fixCombatParsePhase(SPELLLOGSCHOOLOTHER)	-- "(.+) hits (.+). Damage: (%d+) (.+)."
		_L.cp.p[4], _L.cp.o[4] = fixCombatParsePhase(COMBATHITSELFOTHER)
		_L.cp.p[5], _L.cp.o[5] = fixCombatParsePhase(SPELLLOGCRITSELFOTHER)
		_L.cp.p[6], _L.cp.o[6] = fixCombatParsePhase(COMBATHITCRITSELFOTHER)
		_L.cp.p[7], _L.cp.o[7] = fixCombatParsePhase(MISSEDSELFOTHER)
		_L.cp.p[8], _L.cp.o[8] = fixCombatParsePhase(VSPARRYSELFOTHER)
		_L.cp.p[9], _L.cp.o[9] = fixCombatParsePhase(VSEVADESELFOTHER)
	_L.cp.p[10], _L.cp.o[10] = fixCombatParsePhase(VSDODGESELFOTHER)
		_L.cp.p[11], _L.cp.o[11] = fixCombatParsePhase(VSDEFLECTSELFOTHER)
		_L.cp.p[12], _L.cp.o[12] = fixCombatParsePhase(VSBLOCKSELFOTHER)
		_L.cp.p[13], _L.cp.o[13] = fixCombatParsePhase(SPELLBLOCKEDSELFOTHER)
		_L.cp.p[14], _L.cp.o[14] = fixCombatParsePhase(SPELLDEFLECTEDSELFOTHER)
		_L.cp.p[15], _L.cp.o[15] = fixCombatParsePhase(SPELLDODGEDSELFOTHER)
		_L.cp.p[16], _L.cp.o[16] = fixCombatParsePhase(SPELLEVADEDSELFOTHER)
		_L.cp.p[17], _L.cp.o[17] = fixCombatParsePhase(SPELLPARRIEDSELFOTHER)
		_L.cp.p[18], _L.cp.o[18] = fixCombatParsePhase(SPELLRESISTSELFOTHER)
		_L.cp.p[19], _L.cp.o[19] = fixCombatParsePhase(SPELLIMMUNESELFOTHER)
	_L.cp.p[20], _L.cp.o[20] = fixCombatParsePhase(SPELLMISSSELFOTHER)
		_L.cp.p[21], _L.cp.o[21] = fixCombatParsePhase(SPELLLOGCRITOTHER)
		_L.cp.p[22], _L.cp.o[22] = fixCombatParsePhase(SPELLLOGOTHER)
		_L.cp.p[23], _L.cp.o[23] = fixCombatParsePhase(SPELLLOGOTHEROTHER)
		_L.cp.p[24], _L.cp.o[24] = fixCombatParsePhase(SPELLLOGCRITOTHEROTHER)
		_L.cp.p[25], _L.cp.o[25] = fixCombatParsePhase(SPELLBLOCKEDOTHEROTHER)
		_L.cp.p[26], _L.cp.o[26] = fixCombatParsePhase(SPELLDODGEDOTHEROTHER)
		_L.cp.p[27], _L.cp.o[27] = fixCombatParsePhase(SPELLEVADEDOTHEROTHER)
		-- SPELLPARRIEDOTHEROTHER  -- ?
		_L.cp.p[28], _L.cp.o[28] = fixCombatParsePhase(SPELLIMMUNEOTHEROTHER)
		_L.cp.p[29], _L.cp.o[29] = fixCombatParsePhase(SPELLRESISTOTHEROTHER)
	_L.cp.p[30], _L.cp.o[30] = fixCombatParsePhase(SPELLMISSOTHERSELF) -- "(.+)'s (.+) misses (.*)."
		_L.cp.p[31], _L.cp.o[31] = fixCombatParsePhase(SPELLMISSOTHEROTHER)
		_L.cp.p[32], _L.cp.o[32] = fixCombatParsePhase(SPELLIMMUNEOTHEROTHER)  -- "(.+)'s (.+) failed. (.+) is immune."
		_L.cp.p[33], _L.cp.o[33] = fixCombatParsePhase(SPELLMISSOTHEROTHER)	-- dup of [31]
		_L.cp.p[34], _L.cp.o[34] = fixCombatParsePhase(SPELLDEFLECTEDOTHEROTHER)
		_L.cp.p[35], _L.cp.o[35] = fixCombatParsePhase(MISSEDOTHEROTHER)
		_L.cp.p[36], _L.cp.o[36] = fixCombatParsePhase(VSPARRYOTHEROTHER)
		_L.cp.p[37], _L.cp.o[37] = fixCombatParsePhase(VSEVADEOTHEROTHER)
		_L.cp.p[38], _L.cp.o[38] = fixCombatParsePhase(VSDODGEOTHEROTHER)
		_L.cp.p[39], _L.cp.o[39] = fixCombatParsePhase(VSDEFLECTOTHEROTHER)
	_L.cp.p[40], _L.cp.o[40] = fixCombatParsePhase(VSBLOCKOTHEROTHER)
		_L.cp.p[41], _L.cp.o[41] = fixCombatParsePhase(SPELLLOGSCHOOLSELF)	-- "(.+) hits you for (%d+). (.+) blocked"
		_L.cp.p[42], _L.cp.o[42] = fixCombatParsePhase(SPELLLOGSELF)
		_L.cp.p[43], _L.cp.o[43] = fixCombatParsePhase(SPELLLOGCRITSELF)
		_L.cp.p[44], _L.cp.o[44] = fixCombatParsePhase(SPELLLOGOTHERSELF)
		_L.cp.p[45], _L.cp.o[45] = fixCombatParsePhase(SPELLLOGCRITOTHERSELF)
		_L.cp.p[46], _L.cp.o[46] = fixCombatParsePhase(SPELLBLOCKEDOTHERSELF)
		_L.cp.p[47], _L.cp.o[47] = fixCombatParsePhase(SPELLDEFLECTEDOTHERSELF)
		_L.cp.p[48], _L.cp.o[48] = fixCombatParsePhase(SPELLDODGEDOTHERSELF)
		_L.cp.p[49], _L.cp.o[49] = fixCombatParsePhase(SPELLEVADEDOTHERSELF)
		-- SPELLPARRIEDOTHERSELF  -- see below
	_L.cp.p[50], _L.cp.o[50] = fixCombatParsePhase(SPELLIMMUNEOTHERSELF)
		_L.cp.p[51], _L.cp.o[51] = fixCombatParsePhase(SPELLMISSOTHERSELF)
		_L.cp.p[52], _L.cp.o[52] = fixCombatParsePhase(SPELLPARRIEDOTHERSELF) -- "You parry (.+)'s (.+)"
		_L.cp.p[53], _L.cp.o[53] = fixCombatParsePhase(SPELLRESISTOTHERSELF)
		_L.cp.p[54], _L.cp.o[54] = fixCombatParsePhase(MISSEDOTHERSELF)
		_L.cp.p[55], _L.cp.o[55] = fixCombatParsePhase(VSPARRYOTHERSELF)
		_L.cp.p[56], _L.cp.o[56] = fixCombatParsePhase(VSEVADEOTHERSELF)
		_L.cp.p[57], _L.cp.o[57] = fixCombatParsePhase(VSDODGEOTHERSELF)
		_L.cp.p[58], _L.cp.o[58] = fixCombatParsePhase(VSDEFLECTOTHERSELF)
		_L.cp.p[59], _L.cp.o[59] = fixCombatParsePhase(VSBLOCKOTHERSELF)
	_L.cp.p[60], _L.cp.o[60] = fixCombatParsePhase(HEALEDCRITSELFOTHER)
		_L.cp.p[61], _L.cp.o[61] = fixCombatParsePhase(HEALEDSELFOTHER)
		_L.cp.p[62], _L.cp.o[62] = fixCombatParsePhase(PERIODICAURAHEALSELFOTHER)
		_L.cp.p[63], _L.cp.o[63] = fixCombatParsePhase(PERIODICAURAHEALSELFSELF)
	--CombatStats_DumpParsePhases()
end

-------------------------------------------------------------------------------
-- setParseAttackInfoOrder
-------------------------------------------------------------------------------
function setParseAttackInfoOrder()
	-- _L.cp.aio[0] = {creatureName=0,damage=0,damageType=0,spell=0,petName=0,healP=0, kAttackType}
	
	--initialize all to 0
	-- for i=1, 63 do _L.cp.aio[i] = {nil,0,0,0,0,0,0} end
	
	_L.cp.aio[1] = {1,2,3,4,0,0, kDotType}
	_L.cp.aio[2] = {2,3,0,1,0,0, kHitType}
	_L.cp.aio[3] = {2,3,0,1,0,0, kHitType}
	_L.cp.aio[4] = {1,2,0,0,0,0, kHitType}
	_L.cp.aio[5] = {2,3,0,1,0,0, kCritType}
	_L.cp.aio[6] = {1,2,0,0,0,0, kCritType}
	_L.cp.aio[7] = {1,0,0,0,0,0, kMissType}
	_L.cp.aio[8] = {1,0,0,0,0,0, kParryType}
	_L.cp.aio[9] = {1,0,0,0,0,0, kEvadeType}
	_L.cp.aio[10] = {1,0,0,0,0,0, kDodgeType}
	_L.cp.aio[11] = {1,0,0,0,0,0, kDeflectType}
	_L.cp.aio[12] = {1,0,0,0,0,0, kBlockType}
	_L.cp.aio[13] = {2,0,0,1,0,0, kBlockType}
	_L.cp.aio[14] = {2,0,0,1,0,0, kDeflectType}
	_L.cp.aio[15] = {2,0,0,1,0,0, kDodgeType}
	_L.cp.aio[16] = {2,0,0,1,0,0, kEvadeType}
	_L.cp.aio[17] = {2,0,0,1,0,0, kParryType}
	_L.cp.aio[18] = {2,0,0,1,0,0, kResistType}
	_L.cp.aio[19] = {2,0,0,1,0,0, kImmuneType}
	_L.cp.aio[20] = {2,0,0,1,0,0, kMissType}
	
	_L.cp.aio[21] = {2,3,0,0,1,0, kCritType}
	_L.cp.aio[22] = {2,3,0,0,1,0, kHitType}
	_L.cp.aio[23] = {3,4,0,2,1,0, kHitType}
	_L.cp.aio[24] = {3,4,0,2,1,0, kCritType}
	
	_L.cp.aio[25] = {3,0,0,2,1,0, kBlockType}
	_L.cp.aio[26] = {3,0,0,2,1,0, kDodgeType}
	_L.cp.aio[27] = {3,0,0,2,1,0, kEvadeType}
	_L.cp.aio[28] = {3,0,0,2,1,0, kImmuneType}
	_L.cp.aio[29] = {3,0,0,2,1,0, kResistType}
	_L.cp.aio[30] = {3,0,0,2,1,0, kMissType}
	_L.cp.aio[31] = {3,0,0,2,1,0, kMissType}
	_L.cp.aio[32] = {3,0,0,2,1,0, kImmuneType}
	_L.cp.aio[33] = {3,0,0,2,1,0, kMissType}
	_L.cp.aio[34] = {3,0,0,2,1,0, kDeflectType}
	
	_L.cp.aio[35] = {2,0,0,0,1,0, kMissType}
	_L.cp.aio[36] = {2,0,0,0,1,0, kParryType}
	_L.cp.aio[37] = {2,0,0,0,1,0, kEvadeType}
	_L.cp.aio[38] = {2,0,0,0,1,0, kDodgeType}
	_L.cp.aio[39] = {2,0,0,0,1,0, kDeflectType}
	_L.cp.aio[40] = {2,0,0,0,1,0, kBlockType}
	
	_L.cp.aio[41] = {1,2,0,0,0,0, kHitType}
	_L.cp.aio[42] = {1,2,0,0,0,0, kHitType}
	_L.cp.aio[43] = {1,2,0,0,0,0, kCritType}
	
	_L.cp.aio[44] = {1,3,0,2,0,0, kHitType}
	_L.cp.aio[45] = {1,3,0,2,0,0, kCritType}
	_L.cp.aio[46] = {1,0,0,2,0,0, kBlockType}
	_L.cp.aio[47] = {1,0,0,2,0,0, kDeflectType}
	_L.cp.aio[48] = {1,0,0,2,0,0, kDodgeType}
	_L.cp.aio[49] = {1,0,0,2,0,0, kEvadeType}
	_L.cp.aio[50] = {1,0,0,2,0,0, kImmuneType}
	_L.cp.aio[51] = {1,0,0,2,0,0, kMissType}
	_L.cp.aio[52] = {1,0,0,2,0,0, kParryType}
	_L.cp.aio[53] = {1,0,0,2,0,0, kResistType}
	
	_L.cp.aio[54] = {1,0,0,0,0,0, kMissType}
	_L.cp.aio[55] = {1,0,0,0,0,0, kParryType}
	_L.cp.aio[56] = {1,0,0,0,0,0, kEvadeType}
	_L.cp.aio[57] = {1,0,0,0,0,0, kDodgeType}
	_L.cp.aio[58] = {1,0,0,0,0,0, kDeflectType}
	_L.cp.aio[59] = {1,0,0,0,0,0, kBlockType}
	
	_L.cp.aio[60] = {0,0,0,1,0,3, kCritType}
	_L.cp.aio[61] = {0,0,0,1,0,3, kHitType}
	_L.cp.aio[62] = {0,0,0,3,0,2, kHotDotType}
	_L.cp.aio[63] = {0,0,0,2,0,1, kHotDotType}
end

-------------------------------------------------------------------------------
-- parseCombatEvent
-------------------------------------------------------------------------------
function parseCombatEvent(event, msg1)
	local attackType = 0
	local stIdx = 0
	local endIdx = -1
	local i

	if ( event == "CHAT_MSG_COMBAT_SELF_HITS"
		or event == "CHAT_MSG_COMBAT_SELF_MISSES"
		or event == "CHAT_MSG_SPELL_SELF_DAMAGE"
		or event == "CHAT_MSG_SPELL_PERIODIC_HOSTILEPLAYER_DAMAGE"
		or event == "CHAT_MSG_SPELL_PERIODIC_CREATURE_DAMAGE"
		) then
		stIdx = 1
		endIdx = 20
	elseif ( event == "CHAT_MSG_COMBAT_PET_HITS" ) then
		stIdx = 21
		endIdx = 22
	elseif ( event == "CHAT_MSG_SPELL_PET_DAMAGE" ) then
		stIdx = 23
		endIdx = 34
	elseif ( event == "CHAT_MSG_COMBAT_PET_MISSES" ) then
		stIdx = 35
		endIdx = 40
	elseif ( event == "CHAT_MSG_COMBAT_CREATURE_VS_SELF_HITS" ) then
		stIdx = 41
		endIdx = 43
	elseif ( event == "CHAT_MSG_SPELL_CREATURE_VS_SELF_DAMAGE" ) then
		stIdx = 44
		endIdx = 53
	elseif ( event == "CHAT_MSG_COMBAT_CREATURE_VS_SELF_MISSES" ) then
		stIdx = 54
		endIdx = 59
	elseif ( event == "CHAT_MSG_SPELL_SELF_BUFF"
		or event == "CHAT_MSG_SPELL_PARTY_BUFF"
		or event == "CHAT_MSG_SPELL_FRIENDLYPLAYER_BUFF"
		
		--or event == "CHAT_MSG_SPELL_PERIODIC_FRIENDLYPLAYER_BUFFS"
		--or event == "CHAT_MSG_SPELL_PERIODIC_PARTY_BUFFS"
		--or event == "CHAT_MSG_SPELL_PET_BUFF"
		--or event == "CHAT_MSG_SPELL_PERIODIC_SELF_BUFFS"
		--or event == "CHAT_MSG_SPELL_ITEM_ENCHANTMENTS"
		) then
		stIdx = 60
		endIdx = 63
	else
		return 0
	end
	
	-- see if we can match the attack text
	attackType = 0
	for i = stIdx, endIdx do
		_L.tmpStrArr[1], _L.tmpStrArr[2], _L.tmpStrArr[3], _L.tmpStrArr[4], _L.tmpStrArr[5] = string.match(msg1, _L.cp.p[i])
		if (_L.tmpStrArr[1] ~= nil) then
			attackType = i
			
			for i=5, 1, -1 do
				if (_L.tmpStrArr[i] ~= nil) then
					-- strip end '.' on any strings
					_L.tmpStrArr[i] = string.gsub(_L.tmpStrArr[i], "%.$", "")
				end
			end
			break
		end
	end
	
	-- no reason to continue
	if (attackType == 0) then
		CombatStats.ComParse.a = {						-- last attack information
			creatureName = "",
			damage = 0,
			damageType = "",
			spell = "",
			petName = "",
			healP = 0,
		}
		return 0
	end
	
	-- new storage stuff
	if (_L.cp.aio[attackType][1] > 0) then
		CombatStats.ComParse.a.creatureName = _L.tmpStrArr[_L.cp.o[attackType][ _L.cp.aio[attackType][1] ]] end
	if (_L.cp.aio[attackType][2] > 0) then
		CombatStats.ComParse.a.damage = _L.tmpStrArr[_L.cp.o[attackType][ _L.cp.aio[attackType][2] ]] end
	if (_L.cp.aio[attackType][3] > 0) then
		CombatStats.ComParse.a.damageType = _L.tmpStrArr[_L.cp.o[attackType][ _L.cp.aio[attackType][3] ]] end
	if (_L.cp.aio[attackType][4] > 0) then
		CombatStats.ComParse.a.spell = _L.tmpStrArr[_L.cp.o[attackType][ _L.cp.aio[attackType][4] ]] end
	if (_L.cp.aio[attackType][5] > 0) then
		CombatStats.ComParse.a.petName = _L.tmpStrArr[_L.cp.o[attackType][ _L.cp.aio[attackType][5] ]] end
	if (_L.cp.aio[attackType][6] > 0) then
		CombatStats.ComParse.a.healP = _L.tmpStrArr[_L.cp.o[attackType][ _L.cp.aio[attackType][6] ]] end
		
	return attackType
end


--=============================================================================
-- Initialization
--=============================================================================
if (CombatStats and CombatStats.ComParse) then return end;
debugPrint("CS_CombatParse.lua loaded");

-------------------------------------------------------------------------------
-- Public API
-------------------------------------------------------------------------------
if (not CombatStats) then CombatStats = {}; end

CombatStats.ComParse = {
	a = {						-- last attack information
		creatureName = "",
		damage = 0,
		damageType = "",
		spell = "",
		petName = "",
		healP = 0,
		};
		
	Load = load;
	
	ParseCombatEvent = parseCombatEvent;
}

-------------------------------------------------------------------------------
-- Initialize before using
-------------------------------------------------------------------------------
load();
