--[[
	CS_FuBar.lua - Is a support module file for the CombatStats
	World of Warcraft addon.  This module has functions to integrate CombatStats
	into FuBar bar.
	
	Copyright (C) 2008 Brian Beardmore - wowaddon(at)realisticsoftware(dot)com

	Revisions:
		2007.09.21 BAB	Add support for additional options
		2007.09.17 BAB	Put the functionality in this file.
		2007.06.07 BAB	The initial FuBar integration code 
						written by Brian Beardmore.
						
	License:
		This program is free software; you can redistribute it and/or
		modify it under the terms of the GNU General Public License
		as published by the Free Software Foundation; either version 2
		of the License, or (at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program(see GPL.txt); if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
]]

-- Debug switch - set to true, to enable debug output for this module
local debug = false;


-------------------------------------------------------------------------------
-- Function Imports
-------------------------------------------------------------------------------
local debugPrint = CombatStats.Utils.DebugPrint;
local msgPrint = CombatStats.Utils.MsgPrint;

-------------------------------------------------------------------------------
-- Function Prototypes
-------------------------------------------------------------------------------
local load;

local update_BarText;
local init;
local checkDependences;
local create_Globals;
local reset_Globals;

-------------------------------------------------------------------------------
-- Data Members
-------------------------------------------------------------------------------

local _L = {
	haveFuBar = false,
	FuBarPlugin = nil,
	AceTablet = nil,
};

-------------------------------------------------------------------------------
-- Constants
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- Uses
-------------------------------------------------------------------------------
--[[ 	FuBar plugin
]]

-------------------------------------------------------------------------------
-- Loads this module.
-------------------------------------------------------------------------------
function load()
	init();
end

--=============================================================================
-- FuBar functions
--=============================================================================

-------------------------------------------------------------------------------
-- update_BarText
-------------------------------------------------------------------------------
function update_BarText(theText)
	--msgPrint("update_BarText");
	if (_L.FuBarPlugin ~= nil) then
		_L.FuBarPlugin.barText = theText;
		_L.FuBarPlugin.OnTextUpdate();
		--msgPrint("update_BarText with: "..theText)	;
	end
end

-------------------------------------------------------------------------------
-- init
-------------------------------------------------------------------------------
function init()
	-- check if FuBar is available
	_, _, _, _L.haveFuBar, _, _, _ = GetAddOnInfo("FuBar")
	if (_L.haveFuBar == false) then
		return false;
	end
	
	-- check if the needed FuBar sub libraries are available
	if (checkDependences() == false) then
		return false;
	end
	
	-- create the globals
	if (create_Globals() == false) then
		return false;
	end
	
	-- set the default global values
	if (reset_Globals() == false) then
		return false;
	end

	update_BarText(CS_MINIFRAME_DEFAULT_TEXT);
	
	return true;
end

-------------------------------------------------------------------------------
-- checkDependences
-------------------------------------------------------------------------------
function checkDependences()
	local	allDep = true;
	local	aDetailInfo = {};
	
	if (_L.haveFuBar) then
		if (AceLibrary:HasInstance("FuBarPlugin-2.0") == nil) then
			msgPrint(CS_FUBAR_ERR_1);
			aDetailInfo["FubarPlugMissing"] = true;
			allDep = false;
		end
		if (AceLibrary:HasInstance("Tablet-2.0") == nil) then
			--msgPrint("Tablet missing");
			msgPrint(CS_FUBAR_ERR_2);
			aDetailInfo["FubarTabletMissing"] = true;
			allDep = false;
		end
		if (AceLibrary:HasInstance("AceAddon-2.0") == nil) then
			--msgPrint("AceAddon missing");
			msgPrint(CS_FUBAR_ERR_3);
			aDetailInfo["FubarAceMissing"] = true;
			allDep = false;
		end
	else
		aDetailInfo["FubarMissing"] = true;
		allDep = false;
	end
	
	return allDep;
end

-------------------------------------------------------------------------------
-- create_Globals
-------------------------------------------------------------------------------
function create_Globals()
	if (_L.haveFuBar) then
		if (AceLibrary:HasInstance("Tablet-2.0")) then
			_L.AceTablet = AceLibrary("Tablet-2.0");
		else
			return false;
		end
		
		if (AceLibrary:HasInstance("AceAddon-2.0") and AceLibrary:HasInstance("FuBarPlugin-2.0")) then
			_L.FuBarPlugin = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0");
		end
		
		if (_L.FuBarPlugin == nil or _L.AceTablet == nil) then
			_L.FuBarPlugin = nil;
			_L.AceTablet = nil;
			return false;
		end
		
		-- Plugin variables
		_L.FuBarPlugin.barText = "";
		
		-- my addon class function method overrides
		_L.FuBarPlugin.OnTextUpdate = function()
				--msgPrint("_L.FuBarPlugin.OnTextUpdate")
    			_L.FuBarPlugin:SetText(_L.FuBarPlugin.barText);
			end;
		
		_L.FuBarPlugin.OnClick = function()
				--msgPrint("_L.FuBarPlugin.OnClick");	
				
				-- keep in sync with CombatStatsText_OnClick()
				if (CombatStatsDataFrame:IsVisible()) then
					CombatStatsDataFrame:Hide();
				else
					CombatStatsText_ShowFrame();
				end
			end;
		
		_L.FuBarPlugin.OnMenuRequest = {
				type = 'group',
				args = {
					breakline1 = {
						type = "header",
						name = TEXT(CS_FUBAR_MENU_BR_1),
						order = 57,
					},
					CS_CMD_ENABLE = {
						type = "toggle",
						name = TEXT(CS_FUBAR_MENU_INDENT)..TEXT(CS_CMD_ENABLE),
						desc = TEXT(CS_CMD_ENABLE_DESCP_TEXT),
						get = function() return CombatStats.Utils.NumToBool(CombatStats_Config.CombatStats_OnOff) end,
						set = function(val) CombatStats_SetEnable(CombatStats.Utils.BoolToNum(val)); end,
						order = 58,
					},
					CS_CMD_TARGET = {
						type = "toggle",
						name = TEXT(CS_FUBAR_MENU_INDENT)..TEXT(CS_CMD_TARGET),
						desc = TEXT(CS_CMD_TARGET_DESCP_TEXT),
						get = function() return CombatStats.Utils.NumToBool(CombatStats_Config.CombatStats_HideOnNoTarget) end,
						set = function(val) CombatStats_SetTarget(CombatStats.Utils.BoolToNum(val)); end,
						order = 59,
					},
					CS_CMD_MOUSEOVER = {
						type = "toggle",
						name = TEXT(CS_FUBAR_MENU_INDENT)..TEXT(CS_CMD_MOUSEOVER),
						desc = TEXT(CS_CMD_MOUSEOVER_DESCP_TEXT),
						get = function() return CombatStats.Utils.NumToBool(CombatStats_Config.CombatStats_UseMouseOver) end,
						set = function(val) CombatStats_SetMouseOver(CombatStats.Utils.BoolToNum(val)); end,
						order = 60,
					},
					CS_CMD_ENDFLIGHT = {
						type = "toggle",
						name = TEXT(CS_FUBAR_MENU_INDENT)..TEXT(CS_CMD_ENDFLIGHT),
						desc = CS_CMD_ENDFLIGHT_DESCP_TEXT,
						get = function() return CombatStats.Utils.NumToBool(CombatStats_Config.CombatStats_EndOfFight) end,
						set = function(val) CombatStats_SetEndFight(CombatStats.Utils.BoolToNum(val)); end,
						order = 61,
					},
					CS_CMD_HIDE = {
						type = "toggle",
						name = TEXT(CS_FUBAR_MENU_INDENT)..TEXT(CS_CMD_HIDE),
						desc = TEXT(CS_CMD_HIDE_DESCP_TEXT),
						get = function() return CombatStats.Utils.NumToBool(CombatStats_Config.CombatStats_Hide) end,
						set = function(val) CombatStats_SetHide(CombatStats.Utils.BoolToNum(val)); end,
						order = 62,
					},
					CS_CMD_TTIP = {
						type = "toggle",
						name = TEXT(CS_FUBAR_MENU_INDENT)..TEXT(CS_CMD_TTIP),
						desc = TEXT(CS_CMD_TOOLTIP_DESCP_TEXT),
						get = function() return not(CombatStats.Utils.NumToBool(CombatStats_Config.CombatStats_HideTtip)) end,
						set = function(val) CombatStats_SetHideTtip(CombatStats.Utils.BoolToNum(val)); end,
						order = 63,
					},
					breakline2 = {
						type = "header",
						name = TEXT(CS_FUBAR_MENU_BR_2),
						order = 65,
					},
					CS_CMD_SHOWSTAT = {
						type = "execute",
						name = " "..CS_CMD_SHOWSTAT,
						desc = CS_CMD_SHOWSTAT_DESCP_TEXT,
						func = function()
							CombatStatsText_ShowFrame();
							end,
						order = 66,
					},
					CS_CMD_RESET = {
						type = "execute",
						name = " "..CS_CMD_RESET,
						desc = CS_CMD_RESET_TEXT,
						func = function()
							CombatStats_Reset();
							end,
						order = 67,
					},
					CS_CMD_RESETWIN = {
						type = "execute",
						name = " "..CS_CMD_RESETWIN,
						desc = CS_CMD_RESETWIN_TEXT,
						func = function()
							CombatStats_ResetPos();
							end,
						order = 68,
					},
					CS_CMD_SETMAXUPS = {
						type = "execute",
						name = " "..CS_CMD_SETMAXUPS,
						desc = CS_CMD_SETMAXUPS_TEXT,
						func = function()
							CombatStats_SetMaxUPS();
							end,
						order = 69,
					},
				}
			}
			
		-- tooltip
		_L.FuBarPlugin.OnTooltipUpdate = function()
			local cat;
			
			cat = _L.AceTablet:AddCategory(
				'text', CS_TB_TOOLTIP_TEXT,
				'columns', 1,
				'child_textR', 1,
				'child_textG', 1,
				'child_textB', 0
			);
			cat:AddLine(
				'text', ""
			);
		end
		
		return true;
	end
	
	return false;
end

-------------------------------------------------------------------------------
-- reset_Globals
-------------------------------------------------------------------------------
function reset_Globals()
	if (_L.haveFuBar and _L.FuBarPlugin ~= nil) then
		_L.FuBarPlugin.version = kAddonVersion;
		_L.FuBarPlugin.date = kAddonDateStr;
		return true;
	end
	
	return false;
end



--=============================================================================
-- Initialization
--=============================================================================
if (CombatStats and CombatStats.FuBar) then return end;
debugPrint("CS_FuBar.lua loaded");

-------------------------------------------------------------------------------
-- Public API
-------------------------------------------------------------------------------
if (not CombatStats) then CombatStats = {}; end

CombatStats.FuBar = {
	Load = load;
	
	CheckDependences = checkDependences;
	Update_BarText = update_BarText;
}

-------------------------------------------------------------------------------
-- no auto initialization
-------------------------------------------------------------------------------
